/** 
  \file annotation.h
  \brief Declaration of the class to handle annotations created in the ELAN software.
  \version 2.0
  \date July 2012
  \author Tomasz Kapuscinski (tomekkap@prz-rzeszow.pl) and Dawid Warchol (dawwar@o2.pl)
 */

#ifndef __ANNOTATION_H
#define __ANNOTATION_H

#include <string>
#include <vector>
#include <iostream>

using namespace std;

class CTier;

class CAnnotation
{
    public:
		static string FIELDS_SEPARATOR;
		CAnnotation(bool b_isReference=false);
		void Print();
		void SetRange(int p_iStartIndex, int p_iStopindex);
		int GetStartIndex() {return m_iStartIndex;}
		int GetStopIndex() {return m_iStopIndex;}
		void AddField(string p_szField);
		string GetField(int p_iFieldIndex);
		string& GetFieldRef(int p_iFieldIndex);
		void DeleteField(int p_iFieldIndex);
		void DeleteAllFields() {m_oFields.clear();}
		void InsertField(int p_iFieldIndex, string p_szField, bool p_bInsertAfter=false);
		void ReplaceField(int p_iFieldIndex, string p_szField);
		bool Contains(int p_iFieldIndex, string p_szField);
		bool Contains(string p_szField);
		bool IsWithin(int p_iStartFrame, int p_iStopFrame);
		bool HasField(string p_szField);	
		vector<string> GetFields() {return m_oFields;}
		vector<string>& GetFieldsRef() {return m_oFields;}
		int GetFieldsNumber() {return m_oFields.size();}
		bool IsEqualTo(CAnnotation p_oAnnotation);
		bool IsEmpty();
		int GetFramesNumber() {return m_iStopIndex-m_iStartIndex+1;}
		bool BelongsToTier() {return m_bBelongsToTier;}
		void IsReference(bool p_bIsReference){m_bIsReference = p_bIsReference;}
		bool IsReference(){return m_bIsReference;}
		void SetRefTierName(string p_szTierName){m_szRefTierName = p_szTierName;}
		string GetRefTierName(){return m_szRefTierName;}
		void Export(string p_szFile);
		void Export(ofstream &p_oExportFile);
    private:
		void BelongsToTier(bool p_bBelongsToTier) {m_bBelongsToTier = p_bBelongsToTier;}

        int m_iStartIndex;
        int m_iStopIndex;
        vector<string> m_oFields;
		bool m_bBelongsToTier;
		bool m_bIsReference;
		string m_szRefTierName;

		friend class CTier;
};

#endif
