/** 
  \file tier.h
  \brief Declaration of the class to handle tiers (channels with annotations) created in the ELAN software.
  \version 2.0
  \date July 2012
  \author Tomasz Kapuscinski (tomekkap@prz-rzeszow.pl) and Dawid Warchol (dawwar@o2.pl)
 */

#ifndef __TIER_H
#define __TIER_H

#include <string>
#include <vector>
#include "annotation.h"

using namespace std;

class CTier
{
	public:
		CTier();
		void Print();
		void SetName(string p_szName);
		void SetDefaultLocale(string p_szDefaultLocale);
		void SetLinguisticType(string p_szDefaultLinguisticType);
		void SetParentRef(string p_szParentRef);
		void SetAnnotator(string p_szAnnotator);
		void SetParticipant(string p_szParticipant);
		string GetName();
		string GetDefaultLocale();
		string GetLinguisticType();
		string GetParentRef();
		string GetAnnotator();
		string GetParticipant();
		void AddAnnotation(CAnnotation p_oAnnotation);	
		CAnnotation GetAnnotation(int p_iAnnotationIndex);
		vector<CAnnotation> GetAnnotations();
		CAnnotation& GetAnnotationRef(int p_iAnnotationIndex);
		vector<CAnnotation>& GetAnnotationsRef() {return m_oAnnotations;}
		void DeleteAnnotation(int p_iAnnotationIndex);
		void DeleteAllAnnotations() {m_oAnnotations.clear();}
		CAnnotation GetNextAnnotation(CAnnotation p_oAnnotation);
		CAnnotation GetPreviousAnnotation(CAnnotation p_oAnnotation);
		CAnnotation& GetNextAnnotationRef(CAnnotation p_oAnnotation);
		CAnnotation& GetPreviousAnnotationRef(CAnnotation p_oAnnotation);
		void UpdateAnnotationValue(int p_iAnnotationIndex, string p_szAnnotationValue);
		vector<CAnnotation> FilterAnnotations(int p_iFieldIndex, string p_szFieldValue);
		vector<CAnnotation> FilterAnnotations(string p_szFieldValue);
		vector<CAnnotation> FilterAnnotations(int p_iStartFrame, int p_iStopFrame);
		int GetAnnotationsNumber() {return (int)m_oAnnotations.size();}
		void Export(string p_szFile);
		void Export(ofstream &p_oExportFile);
	private:
		string m_szName;
		string m_szDefaultLocale;
		string m_szLinguisticType;
		string m_szAnnotator;
		string m_szParticipant;
		string m_szParentRef;
		vector<CAnnotation> m_oAnnotations;
};

#endif
